@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@ using namespace KSieveUi;
 SelectComparatorComboBox::SelectComparatorComboBox(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent)
     : QComboBox(parent)
 {
-    connect(this, static_cast<void (SelectComparatorComboBox::*)(int)>(&SelectComparatorComboBox::activated), this, &SelectComparatorComboBox::valueChanged);
+    connect(this, QOverload<int>::of(&SelectComparatorComboBox::activated), this, &SelectComparatorComboBox::valueChanged);
     initialize(sieveGraphicalModeWidget->sieveCapabilities());
 }
 
@@ -39,7 +39,7 @@ void SelectComparatorComboBox::initialize(const QStringList &sieveCapabilities)
     addItem(QStringLiteral("i;ascii-casemap"), QStringLiteral("comparator-i;ascii-casemap"));
 
     for (const QString &capability : sieveCapabilities) {
-        if (capability.startsWith(QStringLiteral("comparator-"))) {
+        if (capability.startsWith(QLatin1String("comparator-"))) {
             QString str(capability);
             str.remove(QStringLiteral("comparator-"));
             addItem(str, capability);
