@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -229,12 +229,12 @@ void SieveIncludeWidget::slotHelp()
 {
     const QString help = i18n(
         "The \"include\" command takes an optional \"location\" parameter, an optional \":once\" parameter, an optional \":optional\" parameter, and a single string argument representing the name of the script to include for processing at that point.");
-    const QString href = QStringLiteral("http://tools.ietf.org/html/rfc6609#page-4");
+    const QString href = QStringLiteral("https://tools.ietf.org/html/rfc6609#page-4");
     const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help, href);
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
 }
 
-void SieveIncludeWidget::generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop)
+void SieveIncludeWidget::generatedScript(QString &script, QStringList &requireModules, bool inForEveryPartLoop)
 {
     Q_UNUSED(inForEveryPartLoop);
     QString result;
@@ -242,7 +242,7 @@ void SieveIncludeWidget::generatedScript(QString &script, QStringList &requires,
     mIncludeLister->generatedScript(result, lst);
     if (!result.isEmpty()) {
         script += result;
-        requires << lst;
+        requireModules << lst;
     }
 }
 
@@ -311,9 +311,9 @@ void SieveIncludeWidgetLister::setListOfIncludeFile(const QStringList &listOfInc
     }
 }
 
-void SieveIncludeWidgetLister::generatedScript(QString &script, QStringList &requires)
+void SieveIncludeWidgetLister::generatedScript(QString &script, QStringList &requireModules)
 {
-    requires << QStringLiteral("include");
+    requireModules << QStringLiteral("include");
     const QList<QWidget *> widgetList = widgets();
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
