@@ -19,6 +19,7 @@
 */
 
 #include "sieveeditorwidget.h"
+#include "sievepurposemenuwidget.h"
 
 #include "sieve-editor.h"
 #include "sieveeditortextmodewidget.h"
@@ -34,7 +35,9 @@
 #include <kzip.h>
 #include <KIconEngine>
 #include <KStandardAction>
-#include <QTemporaryFile>
+#include <KMessageBox>
+
+#include <PimCommon/PurposeMenuWidget>
 
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -46,6 +49,7 @@
 #include <QAction>
 #include <QPointer>
 #include <QDir>
+#include <QTemporaryFile>
 
 using namespace KSieveUi;
 
@@ -81,11 +85,23 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     QStringList overlays;
     overlays << QStringLiteral("list-add");
-    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share..."), this);
+    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share Script..."), this);
     connect(mShareScript, &QAction::triggered, this, &SieveEditorWidget::slotShareScript);
     //Add action to toolBar
 
     toolbar->addAction(mShareScript);
+
+    SievePurposeMenuWidget *purposeMenu = new SievePurposeMenuWidget(this, this);
+    if (purposeMenu->menu()) {
+        mShareAction = new QAction(i18n("Share..."), this);
+        mShareAction->setMenu(purposeMenu->menu());
+        mShareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+        purposeMenu->setEditorWidget(this);
+        toolbar->addAction(mShareAction);
+    } else {
+        delete purposeMenu;
+    }
+
     SieveEditorMenuBar *menuBar = nullptr;
     if (useMenuBar) {
         menuBar = new SieveEditorMenuBar;
@@ -117,6 +133,10 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         menuBar->fileMenu()->addSeparator();
         menuBar->fileMenu()->addAction(mShareScript);
         menuBar->toolsMenu()->addSeparator();
+	if (mShareAction) {
+           menuBar->fileMenu()->addAction(mShareAction);
+           menuBar->toolsMenu()->addSeparator();
+	}
         menuBar->toolsMenu()->addAction(mCreateRulesGraphically);
         menuBar->toolsMenu()->addAction(mCheckSyntax);
         lay->addWidget(menuBar);
@@ -137,7 +157,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     mTextModeWidget = new SieveEditorTextModeWidget;
     connect(mTextModeWidget, &SieveEditorTextModeWidget::valueChanged, this, &SieveEditorWidget::slotModified);
-    if (useMenuBar) {
+    if (menuBar) {
         menuBar->setTextModeWidget(mTextModeWidget);
     }
     mStackedWidget->addWidget(mTextModeWidget);
