@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,15 +27,12 @@ class KSieveUi::SieveTextEditWidgetPrivate
 {
 public:
     SieveTextEditWidgetPrivate()
-        : mTextEdit(nullptr)
-        , mSliderContainer(nullptr)
-        , mFindBar(nullptr)
     {
     }
 
-    KSieveUi::SieveTextEdit *mTextEdit;
-    KPIMTextEdit::SlideContainer *mSliderContainer;
-    KPIMTextEdit::PlainTextEditFindBar *mFindBar;
+    KSieveUi::SieveTextEdit *mTextEdit = nullptr;
+    KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
+    KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
 };
 
 SieveTextEditWidget::SieveTextEditWidget(KSieveUi::SieveTextEdit *customTextEdit, QWidget *parent)
