@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -43,7 +43,6 @@ using namespace KSieveUi;
 
 SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *parent)
     : QWidget(parent)
-    , mProcess(nullptr)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setMargin(0);
@@ -109,14 +108,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     mSieveScriptDebuggerWarning->setObjectName(QStringLiteral("sievescriptdebuggerwarning"));
     mainLayout->addWidget(mSieveScriptDebuggerWarning);
 
-    mDebugScript = new QPushButton(i18n("Debug"));
-    mDebugScript->setObjectName(QStringLiteral("debugbutton"));
-    QHBoxLayout *debugButtonLayout = new QHBoxLayout;
-    mainLayout->addLayout(debugButtonLayout);
-    debugButtonLayout->addStretch();
-    debugButtonLayout->addWidget(mDebugScript);
-    mDebugScript->setEnabled(false);
-    connect(mDebugScript, &QPushButton::clicked, this, &SieveScriptDebuggerFrontEndWidget::slotDebugScript);
+    connect(this, &SieveScriptDebuggerFrontEndWidget::debugScriptButtonClicked, this, &SieveScriptDebuggerFrontEndWidget::slotDebugScript);
 }
 
 SieveScriptDebuggerFrontEndWidget::~SieveScriptDebuggerFrontEndWidget()
@@ -124,10 +116,9 @@ SieveScriptDebuggerFrontEndWidget::~SieveScriptDebuggerFrontEndWidget()
     disconnect(mSieveTextEditWidget->textEdit(), &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
 }
 
-
 void SieveScriptDebuggerFrontEndWidget::updateDebugButton()
 {
-    mDebugScript->setEnabled(!mSieveTextEditWidget->textEdit()->document()->isEmpty() && !mEmailPath->lineEdit()->text().trimmed().isEmpty());
+    Q_EMIT debugButtonEnabled(!mSieveTextEditWidget->textEdit()->document()->isEmpty() && !mEmailPath->lineEdit()->text().trimmed().isEmpty());
 }
 
 void SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged()
@@ -169,7 +160,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
         delete temporaryFile;
         return;
     }
-    mDebugScript->setEnabled(false);
+    Q_EMIT debugButtonEnabled(false);
     QTextStream stream(temporaryFile);
     stream << mSieveTextEditWidget->textEdit()->toPlainText();
     temporaryFile->flush();
@@ -190,16 +181,14 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
     mProcess->start(QStringLiteral("sieve-test"), QStringList() << arguments);
     connect(mProcess, &QProcess::readyReadStandardOutput, this, &SieveScriptDebuggerFrontEndWidget::slotReadStandardOutput);
     connect(mProcess, &QProcess::readyReadStandardError, this, &SieveScriptDebuggerFrontEndWidget::slotReadErrorOutput);
-    connect(mProcess, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotDebugFinished()));
-    //TODO port to new connect api
-    //connect(mProcess, &QProcess::finished, this, &SieveScriptDebuggerFrontEndWidget::slotDebugFinished);
+    connect(mProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &SieveScriptDebuggerFrontEndWidget::slotDebugFinished);
     mSieveTestResult->editor()->appendPlainText(QStringLiteral("--------------------------------------"));
     mSieveTestResult->editor()->appendPlainText(QLocale().toString(QDateTime::currentDateTime()));
     mSieveTestResult->editor()->appendPlainText(QStringLiteral("\n"));
     if (!mProcess->waitForStarted()) {
         delete mProcess;
         mProcess = nullptr;
-        mDebugScript->setEnabled(true);
+        Q_EMIT debugButtonEnabled(true);
     }
 }
 
@@ -219,7 +208,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugFinished()
 {
     delete mProcess;
     mProcess = nullptr;
-    mDebugScript->setEnabled(true);
+    Q_EMIT debugButtonEnabled(true);
 }
 
 QString SieveScriptDebuggerFrontEndWidget::script() const
@@ -236,7 +225,7 @@ void SieveScriptDebuggerFrontEndWidget::setScript(const QString &script)
 bool SieveScriptDebuggerFrontEndWidget::canAccept() const
 {
     const QString script = mSieveTextEditWidget->textEdit()->toPlainText();
-    if (script.contains(QStringLiteral("debug_log")) || script.contains(QStringLiteral("vnd.dovecot.debug"))) {
+    if (script.contains(QLatin1String("debug_log")) || script.contains(QLatin1String("vnd.dovecot.debug"))) {
         mSieveScriptDebuggerWarning->setErrorMessage(i18n("Script still contains debug method. Remove it please."));
         return false;
     }
